referrerpolicy=no-referrer-when-downgrade

Config

Trait Config 

pub trait Config:
    Config<RuntimeEvent: From<Event<Self>>>
    + Config
    + Config<RuntimeEvent: From<Event<Self>>> {
    type Assets: Balanced<Self::AccountId, Balance = <<Self as Config>::OnChargeTransaction as OnChargeTransaction<Self>>::Balance>;
    type PGASAssetId: Get<<<Self as Config>::Assets as Inspect<<Self as Config>::AccountId>>::AssetId>;
    type CallFilter: Contains<<Self as Config>::RuntimeCall>;
    type WeightInfo: WeightInfo;
    type BenchmarkHelper: BenchmarkHelperTrait<Self::AccountId, <<Self as Config>::Assets as Inspect<<Self as Config>::AccountId>>::AssetId, <<Self as Config>::OnChargeTransaction as OnChargeTransaction<Self>>::Balance>;
}
Configuration trait of this pallet.

The main purpose of this trait is to act as an interface between this pallet and the runtime in which it is embedded in. A type, function, or constant in this trait is essentially left to be configured by the runtime that includes this pallet.

Consequently, a runtime that wants to include this pallet must implement this trait.

Required Associated Types

type Assets: Balanced<Self::AccountId, Balance = <<Self as Config>::OnChargeTransaction as OnChargeTransaction<Self>>::Balance>

Access to the PGAS asset.

type PGASAssetId: Get<<<Self as Config>::Assets as Inspect<<Self as Config>::AccountId>>::AssetId>

The PGAS asset id.

type CallFilter: Contains<<Self as Config>::RuntimeCall>

Filter deciding which calls are eligible to be paid with PGAS.

type WeightInfo: WeightInfo

Weight information for the extension.

type BenchmarkHelper: BenchmarkHelperTrait<Self::AccountId, <<Self as Config>::Assets as Inspect<<Self as Config>::AccountId>>::AssetId, <<Self as Config>::OnChargeTransaction as OnChargeTransaction<Self>>::Balance>

Helper used by the extension benchmarks to endow the caller with enough PGAS to cover the fee.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors